==> dde-shell_1.99.36.tar.xz: BUILD/panels/notification/center/translations/org.deepin.ds.notificationcenter_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>GroupNotify</name>
    <message>
        <source>Clear All</source>
        <translation>Limpar tudo</translation>
    </message>
</context>
<context>
    <name>NotifyHeader</name>
    <message>
        <source>Notification Center</source>
        <translation>Central de Notificações</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation>Limpar tudo</translation>
    </message>
</context>
<context>
    <name>NotifySetting</name>
    <message>
        <source>Unpin</source>
        <translation>Desafixar</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>Fixar</translation>
    </message>
    <message>
        <source>Notification Setting</source>
        <translation>Configurações de Notificações</translation>
    </message>
</context>
<context>
    <name>notifycenter::AppNotifyItem</name>
    <message>
        <source>Just now</source>
        <translation>Há pouco</translation>
    </message>
    <message>
        <source>%1 minutes ago</source>
        <translation>%1 minutos atrás</translation>
    </message>
    <message>
        <source>1 hour ago</source>
        <translation>1 hora atrás</translation>
    </message>
    <message>
        <source>%1 hours ago</source>
        <translation>%1 horas atrás</translation>
    </message>
    <message>
        <source>Yesterday </source>
        <translation>Ontem</translation>
    </message>
</context>
</TS>

==> dde-shell_2.0.1.tar.xz: BUILD/panels/notification/center/translations/org.deepin.ds.notificationcenter_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_BR">
<context>
    <name>GroupNotify</name>
    <message>
        <source>Clear All</source>
        <translation>Limpar tudo</translation>
    </message>
</context>
<context>
    <name>NotifyHeader</name>
    <message>
        <source>Notification Center</source>
        <translation>Central de Notificações</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation>Limpar tudo</translation>
    </message>
</context>
<context>
    <name>NotifySetting</name>
    <message>
        <source>Unpin</source>
        <translation>Desafixar</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>Fixar</translation>
    </message>
    <message>
        <source>Notification Setting</source>
        <translation>Configurações de Notificações</translation>
    </message>
</context>
<context>
    <name>notifycenter::AppNotifyItem</name>
    <message>
        <source>Just now</source>
        <translation>Há pouco</translation>
    </message>
    <message>
        <source>%1 minutes ago</source>
        <translation>%1 minutos atrás</translation>
    </message>
    <message>
        <source>1 hour ago</source>
        <translation>1 hora atrás</translation>
    </message>
    <message>
        <source>%1 hours ago</source>
        <translation>%1 horas atrás</translation>
    </message>
    <message>
        <source>Yesterday </source>
        <translation>Ontem</translation>
    </message>
</context>
</TS>
